from datetime import datetime, date
from django import template
from django.utils.safestring import mark_safe

register = template.Library()


def is_expired(value):
    return value < datetime.now().date()


def expires_next_year(value):
    return value < date(date.today().year + 1, 12, 31)


@register.filter(is_safe=True)
def expiration_class(value):
    if not value:
        return

    if is_expired(value):
        return mark_safe('class="danger"')
    elif expires_next_year(value):
        return mark_safe('class="warning"')
    else:
        return


@register.filter(is_safe=True)
def coverage_class(value):
    print(value)

    if not value:
        return mark_safe('class="danger"')



from django.http import HttpResponse
from django.urls import path


def dummy_view(request):
    html = "<html><body>Cisco Support API plugin.</body></html>"
    return HttpResponse(html)


urlpatterns = [
    path("", dummy_view, name="cisco_support_list"),
]



from extras.plugins import PluginConfig
from .version import __version__


class CiscoSupportConfig(PluginConfig):
    name = 'netbox_cisco_support'
    verbose_name = 'Cisco Support APIs'
    description = 'Gathering device info using Cisco Support APIs'
    version = __version__
    author = 'Timo Reimann'
    author_email = 'timo@goebelmeier.de'
    base_url = 'cisco-support'
    min_version = '2.11.1'
    required_settings = []
    default_settings = {
        'device_ext_page': 'right'
    }


config = CiscoSupportConfig



# Generated by Django 3.2.5 on 2021-07-22 19:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_cisco_support', '0003_auto_20210722_1917'),
    ]

    operations = [
        migrations.AddField(
            model_name='ciscosupport',
            name='is_covered',
            field=models.BooleanField(default=False),
        ),
    ]



from datetime import datetime

from django.shortcuts import get_object_or_404

from extras.plugins import PluginTemplateExtension
from .models import CiscoDeviceTypeSupport, CiscoSupport


class CiscoDeviceTypeSupportInformation(PluginTemplateExtension):
    model = 'dcim.devicetype'

    def right_page(self):
        try:
            cisco_device_type_support = CiscoDeviceTypeSupport.objects.get(device_type=self.context['object'])
        except CiscoDeviceTypeSupport.DoesNotExist:
            print("No Cisco Device Type Support Entry found")
            cisco_device_type_support = None

        return self.render('netbox_cisco_support/cisco_support_device_type.html', {
            'cisco_device_type_support': cisco_device_type_support
        })


class CiscoDeviceSupportInformation(PluginTemplateExtension):
    model = 'dcim.device'

    def right_page(self):
        try:
            cisco_device_support = CiscoSupport.objects.get(device=self.context['object'])
        except CiscoSupport.DoesNotExist:
            print("No Cisco Device Support Entry found")
            cisco_device_support = None

        try:
            cisco_device_type_support = CiscoDeviceTypeSupport.objects.get(device_type=self.context['object'].device_type)
        except CiscoDeviceTypeSupport.DoesNotExist:
            print("No Cisco Device Type Support Entry found")
            cisco_device_type_support = None

        return self.render('netbox_cisco_support/cisco_support_device.html', {
            'cisco_device_support': cisco_device_support,
            'cisco_device_type_support': cisco_device_type_support
        })


template_extensions = [CiscoDeviceTypeSupportInformation, CiscoDeviceSupportInformation]



# Generated by Django 3.2.5 on 2021-07-22 18:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0131_consoleport_speed'),
        ('netbox_cisco_support', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='CiscoDeviceTypeSupport',
            fields=[
                ('created', models.DateField(auto_now_add=True, null=True)),
                ('last_updated', models.DateTimeField(auto_now=True, null=True)),
                ('id', models.BigAutoField(primary_key=True, serialize=False)),
                ('end_of_sale_date', models.DateField()),
                ('end_of_sw_maintenance_releases', models.DateField()),
                ('end_of_security_vul_support_date', models.DateField()),
                ('end_of_routine_failure_analysis_date', models.DateField()),
                ('end_of_service_contract_renewal', models.DateField()),
                ('last_date_of_support', models.DateField()),
                ('end_of_svc_attach_date', models.DateField()),
                ('device_type', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='dcim.devicetype')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from django.contrib import admin
from .models import CiscoDeviceTypeSupport, CiscoSupport


@admin.register(CiscoDeviceTypeSupport)
class CiscoSupportAdmin(admin.ModelAdmin):
    list_display = (
        "device_type",
        "end_of_sale_date",
        "end_of_sw_maintenance_releases",
        "end_of_security_vul_support_date",
        "end_of_routine_failure_analysis_date",
        "end_of_service_contract_renewal",
        "last_date_of_support",
        "end_of_svc_attach_date"
    )


@admin.register(CiscoSupport)
class CiscoSupportAdmin(admin.ModelAdmin):
    list_display = (
        "device",
        "is_covered",
        "coverage_end_date",
        "warranty_end_date"
    )



# Generated by Django 3.2.5 on 2021-07-22 19:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_cisco_support', '0002_ciscodevicetypesupport'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_routine_failure_analysis_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_sale_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_security_vul_support_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_service_contract_renewal',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_svc_attach_date',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='end_of_sw_maintenance_releases',
        ),
        migrations.RemoveField(
            model_name='ciscosupport',
            name='last_date_of_support',
        ),
    ]
